"""
TyConf - Type-safe Configuration Management

TyConf (Typed Config) is a modern Python library for managing application
configuration with runtime type validation and an intuitive API.
"""

from .core import TyConf, PropertyDescriptor

__all__ = ["TyConf", "PropertyDescriptor"]
__version__ = "1.0.0"
__date__ = "2025-11-18"
__author__ = "barabasz"
__license__ = "MIT"
__copyright__ = "2025, barabasz"
__url__ = "https://github.com/barabasz/tyconf"
